pub fn is_top_level(scope_stack: &[ScopeFlags]) -> boolExpand description
if current visit path is top level including such scenario:
class T {
[foo]() {}
}
class A {
static {
foo;
}
}
foo;
{
foo;
}pub fn is_top_level(scope_stack: &[ScopeFlags]) -> boolif current visit path is top level including such scenario:
class T {
[foo]() {}
}
class A {
static {
foo;
}
}
foo;
{
foo;
}